@@ -1,8 +1,8 @@
 # entire dataset ------------------------------------------------
 
 test_that(
-  desc = "checking ggscatterstats with entire dataset",
-  code = {
+  "checking ggscatterstats with entire dataset",
+  {
     set.seed(123)
     expect_doppelganger(
       title = "parametric correlation - without NAs",
@@ -20,12 +20,15 @@ test_that(
 # aesthetic modifications work ---------------------------------------------
 
 test_that(
-  desc = "aesthetic modifications work",
-  code = {
+  "aesthetic modifications work",
+  {
     set.seed(123)
     expect_doppelganger(
       title = "changing scales and aesthetics",
-      fig = ggscatterstats(mtcars, wt, mpg,
+      fig = ggscatterstats(
+        mtcars,
+        wt,
+        mpg,
         results.subtitle = FALSE,
         xsidehistogram.args = list(
           fill = "red",
@@ -91,13 +94,13 @@ test_that("labeling variables and expressions work as expected", {
 # subtitle output ----------------------------------------------------------
 
 test_that(
-  desc = "subtitle output - ggscatterstats",
-  code = {
+  "subtitle output - ggscatterstats",
+  {
     set.seed(123)
     p_sub <- ggscatterstats(
-      data = dplyr::starwars,
-      x = mass,
-      y = height,
+      data = ggplot2::msleep,
+      x = sleep_total,
+      y = bodywt,
       conf.level = 0.90,
       type = "r"
     ) %>%
@@ -105,9 +108,9 @@ test_that(
 
     set.seed(123)
     fun_sub <- corr_test(
-      data = dplyr::starwars,
-      x = mass,
-      y = height,
+      data = ggplot2::msleep,
+      x = sleep_total,
+      y = bodywt,
       conf.level = 0.90,
       type = "r"
     )$expression[[1L]]
@@ -117,8 +120,8 @@ test_that(
 )
 
 test_that(
-  desc = "grouped_ggscatterstats plotting works as expected",
-  code = {
+  "grouped_ggscatterstats plotting works as expected",
+  {
     set.seed(123)
     expect_doppelganger(
       title = "defaults work as expected",
@@ -148,8 +151,8 @@ test_that(
 )
 
 test_that(
-  desc = "grouped_ggscatterstats errors when no grouping is present",
-  code = {
+  "grouped_ggscatterstats errors when no grouping is present",
+  {
     expect_snapshot_error(
       grouped_ggscatterstats(
         data = iris,
